// light mapping pixel shader

//textures seem to bind 1 to 1 with texture units
uniform sampler2D planeTex;
uniform sampler2D cubeTex;
uniform sampler2D brickTex;
uniform sampler2D normalTexId;
//uniform float red;

varying vec3 LightDir;
varying vec3 EyeDir;
varying vec3 VNormal;
//uniform vec3 SurfaceColor;    = (0.7, 0.6, 0.18)


void main()
{
    float SpecularFactor = 0.5;


    vec4 lightTex = texture2D(planeTex, gl_TexCoord[0].st);
    vec4 normalTex = texture2D(normalTexId, gl_TexCoord[0].st);


    vec4 color = gl_Color;

    vec3 SurfaceColor = vec3(color.x, color.y, color.z);

    // without a normal peturbation, the normal will be (0, 0, 1)
    // in tangent space

    vec3 Normal = vec3(normalTex.x, normalTex.y, normalTex.z);
    Normal.x -= 0.5;
    Normal.y -= 0.5;
    Normal.z -= 0.5;

    Normal.x *= 2.0;
    Normal.y *= 2.0;
    Normal.z *= 2.0;

    Normal = vec3(0, 0, 1);


    vec3 litColor;
    litColor = SurfaceColor * max(dot(Normal, LightDir), 0.0);
    vec3 reflectDir = reflect(LightDir, Normal);
    float spec = max(dot(EyeDir, reflectDir), 0.0);
    spec = pow(spec, 6.0);
    spec *= SpecularFactor;
    litColor = min(litColor + spec, vec3(1.0));
    gl_FragColor = vec4(litColor, 1.0);

}

